#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-LN4PZWALM0nAyWtlGZbtK9
key:                  hspec-expectations-0.8.2-LN4PZWALM0nAyWtlGZbtK9
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  30bde6ef333f050d8bf85926a24e50ce
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-LN4PZWALM0nAyWtlGZbtK9
depends:
    HUnit-1.6.2.0-8FsjWfKzSV74wDnwnuEJe4 base-4.14.2.0
    call-stack-0.3.0-HaJG5jRa2XM74od97nDj56

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

